// =========
// = Photo functions, specific to the dashboard =
// =========


//var used to track whether photos have been loaded yet or not (to save memory)
var Photos_loaded = false;

function Photos_resetPhotos() {
	
	//create loading icons
	var loader;
	if(document.getElementById('loading') == null) {
		var loader = document.createElement("img");
		loader.setAttribute("id","loading");
		loader.setAttribute("src","Images/load_indicator.gif");	
		$('pageCount').appendChild(loader);
	}

	//hide forward/back buttons
	hide('back');
	hide('forward');

	Photos_removePhotos();

	//make temp photos
	var tempPhotos = [
		{"url":"","thumbUrl":"Images/blank.png","title":"Loading"},
		{"url":"","thumbUrl":"Images/blank.png","title":"Loading"},
		{"url":"","thumbUrl":"Images/blank.png","title":"Loading"},
	];
	for(var i = 0; i < tempPhotos.length; i++) {
		Photos_makePhotoDiv(tempPhotos[i],5 + i * 100);
	}

}

function Photos_placePhotos (photos) {
	var leftset;

	//remove photos already there, if any
	Photos_removePhotos();

	for (var i = 0; i < photos.length; i++) {
			leftset = 5 + (i * 100); //100 = photo's width
			Photos_makePhotoDiv(photos[i],leftset);
	}

	Photos_numPages = Math.ceil(photos.length / 3);
	Photos_curPage = 0;
	
}

function Photos_removePhotos () {
	
	var photosDiv = document.getElementById('photos');
	var cur_photos = photosDiv.getElementsByTagName('div');

	var photo_array = new Array();
	for (var i = 0; i < cur_photos.length; i++)
		photo_array.push(cur_photos[i]);

	for(var i = 0; i < photo_array.length; i++)
		photosDiv.removeChild(photo_array[i]);
	
}

function Photos_makePhotoDiv (photo,left) {
	
	//create containing photo
	var photoDiv = document.createElement("div");
	photoDiv.setAttribute("class","pcol");
	photoDiv.style.left = left + "px";
	
	var a = document.createElement("a");
	a.setAttribute("class","canvas");
	addEvent(a,'mousemove',function() { var title = this.parentNode.getElementsByTagName('span').item(0); if (title.style.opacity == 0) title.style.opacity = 1;},true);
	addEvent(a,'mouseout',function() { var title = this.parentNode.getElementsByTagName('span').item(0); var fader = new Fader(title,null,300); fader.fadeOut();},true);
	
	if (photo.url != null) addEvent(a,"click",linkTo(photo.linkUrl));
	photoDiv.appendChild(a);
	
	var img = document.createElement("img");
	img.setAttribute("src",photo.thumbUrl);
	photoDiv.appendChild(img);

	var span = document.createElement("span");
	span.setAttribute("class","title");
	span.innerHTML = photo.title;
	photoDiv.appendChild(span);
	
	document.getElementById('photos').appendChild(photoDiv);
}

// Kicks everything off.  
function Photos_loadPhotos(photos) {

	Photos_placePhotos(photos);

	var pics = document.getElementById('photos').getElementsByTagName('div');
	var width = 300;
	
	if (mover) {
		delete mover;
	}
	
	mover = new MoveSet(pics, width, 600,Photos_checkBoundsOnComplete,5,205);
	
	Photos_checkBoundsOnComplete(); //run this initially to set off bound call and remove the forward button
}

function Photos_checkBoundsOnComplete() {
	var leftmost; var rightmost;
	
	if (mover == null) return false;
	
	Photos_curPage += (mover.direction == 'left' ? -1 : 1);
	$('pageCount').innerHTML = Photos_curPage + "/" + Photos_numPages;
	
	leftmost = mover.findFarthestPic('left'); 
	rightmost = mover.findFarthestPic('right');
	
	if (leftmost >= mover.leftBounds) {
		//Pictures far left as possible
		hide('back');
		show('forward');
		
	} else if (rightmost <= mover.rightBounds) {
		//Pictures are as far right as possible
		
		hide('forward');
		show('back');
		
	} else {
		//in the middle
		
		show('forward');
		show('back');
	}
}

function Photos_setPhotoFeedTitle (feed) {
	$('photosetTitle').innerHTML = Photos_FEEDS[indexOfValue(feed,Photos_FEEDS)].name;
}

function Photos_makeFeedSelectBox() {
	
	var feeds = Photos_FEEDS;
	
	if (prefs.getPhotoFeed() != null) {//set the select box to the current feed
		var index = indexOfValue(prefs.getPhotoFeed(),feeds);
		if (feeds[index] != null) feeds[index].selected = true;
	}
	
	makeSelectBox('photoFeedSelect',feeds,Photos_changePhotoFeed);
}

function Photos_changePhotoFeed() {
	var feed = this.options[this.selectedIndex].value;
	
	Photos_retrieve(feed, Photos_loadPhotos);
}

Photos_FEEDS = [
	{"name":"Approver's Choice", "value":"approvers_choice_photos.xml"},
	{"name":"Outdoor Photos","value":"outdoor_photos.xml"},
	{"name":"Weather Photos","value":"weather_photos.xml"},
	{"name":"--------------","disabled":true},
	{"name":"Agriculture","value":"agriculture_photos.xml"},
	{"name":"Architecture","value":"architecture_photos.xml"},
	{"name":"Astronomy","value":"astronomy_photos.xml"},
	{"name":"Barns","value":"barns_photos.xml"},
	{"name":"Beaches","value":"beach_photos.xml"},
	{"name":"Birds","value":"birds_photos.xml"},
	{"name":"Boats","value":"boats_photos.xml"},
	{"name":"Bridges","value":"bridges_photos.xml"},
	{"name":"Cell phone","value":"cell_phone_photos.xml"},
	{"name":"City Skyline","value":"city_skyline_photos.xml"},
	{"name":"Clouds","value":"clouds_photos.xml"},
	{"name":"Cold Snap","value":"cold_snap_photos.xml"},
	{"name":"Desert","value":"desert_photos.xml"},
	{"name":"Dust Devils","value":"dust_devil_photos.xml"},
	{"name":"Fire","value":"fire_photos.xml"},
	{"name":"Floods","value":"flood_photos.xml"},
	{"name":"Flowers","value":"flowers_photos.xml"},
	{"name":"Fog","value":"fog_photos.xml"},
	{"name":"From the sky","value":"from_the_sky_photos.xml"},
	{"name":"Hail","value":"hail_photos.xml"},
	{"name":"Heat Wave","value":"heat_wave_photos.xml"},
	{"name":"Holiday","value":"holidays_photos.xml"},
	{"name":"Ice Storm","value":"ice_storm_photos.xml"},
	{"name":"Insects","value":"insects_photos.xml"},
	{"name":"Lighthouses","value":"lighthouses_photos.xml"},
	{"name":"Lightning","value":"lightning_photos.xml"},
	{"name":"Manipulated Images","value":"manipulated_images_photos.xml"},
	{"name":"Mountains","value":"mountains_photos.xml"},
	{"name":"Natural Disasters","value":"natural_disasters_photos.xml"},
	{"name":"Nighttime","value":"nighttime_photos.xml"},
	{"name":"Pets","value":"pets_photos.xml"},
	{"name":"Rain","value":"rain_photos.xml"},
	{"name":"Rainbow","value":"rainbow_photos.xml"},
	{"name":"Sky","value":"sky_photos.xml"},
	{"name":"Snow","value":"snow_photos.xml"},
	{"name":"Storm Damage","value":"storm_damage_photos.xml"},
	{"name":"Sunrise/Sunset","value":"sunrise_sunset_photos.xml"},
	{"name":"Thunderstorms","value":"thunderstorm_photos.xml"},
	{"name":"Tornado","value":"tornado_photos.xml"},
	{"name":"Trains","value":"trains_photos.xml"},
	{"name":"Trees","value":"trees_photos.xml"},
	{"name":"Tropical","value":"tropical_photos.xml"},
	{"name":"Tropical Storm","value":"tropical_storm_photos.xml"},
	{"name":"Vehicles","value":"vehicles_photos.xml"},
	{"name":"Water","value":"water_photos.xml"},
	{"name":"Waterfalls","value":"waterfalls_photos.xml"},
	{"name":"Waves","value":"waves_photos.xml"},
	{"name":"Wild Animals","value":"wild_animals_photos.xml"},
	{"name":"Windmills","value":"windmills_photos.xml"},
	{"name":"Winter","value":"winter_photos.xml"},
	{"name":"Winter Sports","value":"winter_sports_photos.xml"},
	{"name":"Zoos","value":"zoos_photos.xml"}
];